@@ -1,6 +1,6 @@
 package DefHash;
 
-our $VERSION = '1.0.4'; # VERSION
+our $VERSION = '1.0.6'; # VERSION
 
 1;
 # ABSTRACT: Define things according to a specification, using hashes
@@ -17,7 +17,7 @@ DefHash - Define things according to a specification, using hashes
 
 =head1 VERSION
 
-version 1.0.4
+This document describes version 1.0.6 of DefHash (from Perl distribution DefHash), released on 2014-10-22.
 
 =head1 HOMEPAGE
 
@@ -25,7 +25,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/DefHash>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-DefHash>.
+Source repository is at L<https://github.com/perlancar/perl-DefHash>.
 
 =head1 BUGS
 
@@ -37,11 +37,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
